package com.microservices.dms.achievementLibrary.mapper;

import java.util.List;

import com.microservices.common.datasource.annotation.Slave;
import com.microservices.dms.achievementLibrary.domain.SchoolEnterpriseAchievements;
import org.apache.ibatis.annotations.Mapper;

/**
 * 校企成果Mapper接口
 * 
 * @author microservices
 * @date 2025-04-03
 */
@Mapper
@Slave
public interface SchoolEnterpriseAchievementsMapper 
{
    /**
     * 查询校企成果
     * 
     * @param id 校企成果主键
     * @return 校企成果
     */
    public SchoolEnterpriseAchievements selectSchoolEnterpriseAchievementsById(Long id);

    /**
     * 查询校企成果列表
     * 
     * @param schoolEnterpriseAchievements 校企成果
     * @return 校企成果集合
     */
    public List<SchoolEnterpriseAchievements> selectSchoolEnterpriseAchievementsList(SchoolEnterpriseAchievements schoolEnterpriseAchievements);

    /**
     * 新增校企成果
     * 
     * @param schoolEnterpriseAchievements 校企成果
     * @return 结果
     */
    public int insertSchoolEnterpriseAchievements(SchoolEnterpriseAchievements schoolEnterpriseAchievements);

    /**
     * 修改校企成果
     * 
     * @param schoolEnterpriseAchievements 校企成果
     * @return 结果
     */
    public int updateSchoolEnterpriseAchievements(SchoolEnterpriseAchievements schoolEnterpriseAchievements);

    /**
     * 删除校企成果
     * 
     * @param id 校企成果主键
     * @return 结果
     */
    public int deleteSchoolEnterpriseAchievementsById(Long id);

    /**
     * 批量删除校企成果
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSchoolEnterpriseAchievementsByIds(Long[] ids);

    Long topStatistic(SchoolEnterpriseAchievements schoolEnterpriseAchievements);
}
